#ifndef EDV_DATE_FORMAT_H
#define EDV_DATE_FORMAT_H


/*
 *	Date Relativity:
 */
typedef enum {
	EDV_DATE_RELATIVITY_ABSOLUTE,	/* Relative to christian time */
	EDV_DATE_RELATIVITY_CURRENT	/* Relative to current time */
} edv_date_relativity;


/*
 *	Formats a date and time relative to the current time.
 *
 *	The ctx specifies the Endeavour 2 Context.
 *
 *	The t specifies the time in seconds since EPOCH.
 *
 *	Returns a statically allocated string describing the date and
 *	time relative to the current time or NULL on error.
 */
extern const gchar *EDVDateStringCurrent(
        edv_context_struct *ctx,
        const gulong t
);

/*
 *	Formats a date and time string relative to the Common Era of
 *	current locale.
 *
 *	The format of the date & time is specified by the configuration
 *	on the context.
 *
 *	The ctx specifies the Endeavour 2 Context.
 *
 *	The t specifies the time in seconds since EPOCH.
 *
 *	Returns a statically allocated string describing the date and
 *	time relative to the Common Era of the current locale or NULL
 *	on error.
 */
extern const gchar *EDVDateStringAbsolute(
        edv_context_struct *ctx,
        const gulong t
);

/*
 *	Formats a date and time string specified by the configuration.
 *
 *	The format and relativity of the date & time is specified by
 *	the configuration on the context.
 *
 *	The ctx specifies the Endeavour 2 Context.
 *
 *	The t specifies the time in seconds since EPOCH.
 *
 *	Returns a statically allocated string describing the date and
 *	time specified by the configuration or NULL on error.
 */
extern const gchar *EDVDateString(
	edv_context_struct *ctx,
	const gulong t
);


/*
 *	Formats a date and time string describing the time lapsed in
 *	the format of "<n1> <units1> <n2> <units2>".
 *
 *	The ctx specifies the Endeavour 2 Context.
 *
 *	The dt specifies the time lapsed in seconds. If dt is 0 then
 *	"less than a second" will be returned.
 *
 *	Returns a statically allocated string describing the
 *	time lapsed.
 */
extern const gchar *EDVDateStringDuration(
	edv_context_struct *ctx,
	const gulong dt
);


#endif	/* EDV_DATE_FORMAT_H */
