/*
		     Endeavour Devices List File IO
 */

#ifndef EDV_DEVICES_LIST_H
#define EDV_DEVICES_LIST_H

#include <glib.h>
#include "edv_device.h"


/*
 *	Updates the Devices' mount states with the current mount
 *	states obtained from the system.
 *
 *	Each Device's flags member's EDV_DEVICE_MOUNTED flag will
 *	be either set or unset.
 *
 *	The devices_list specifies the Devices List.
 */
extern void EDVDevicesListUpdateMountStatesFromSystem(GList *devices_list);

/*
 *	Updates the Device's statistics with the statistics obtained
 *	from the system.
 *
 *	The Device's blocks_total, blocks_available, blocks_free,
 *	block_size, indicies_total, indicies_free, fs_id, and
 *	name_length_max members will be updated by this call.
 *
 *	EDVDeviceUpdateMountState() should always be called prior to
 *	this call to ensure that the mount states are up to date.
 *
 *	The d specifies the Device.
 */
extern void EDVDevicesListUpdateStatsFromSystem(GList *devices_list);


/*
 *	Opens the Devices List from the Devices List file.
 *
 *	The devices_list specifies the Devices List, a GList of
 *	edv_device_struct * Devices. The Devices opened from the
 *	Devices List file will be appended to the Devices List.
 *
 *	The path specifies the Devices List file.
 *
 *	Returns the Devices List, a GList of edv_device_struct *
 *	Devices.
 */
extern GList *EDVDevicesListFileOpen(
        GList *devices_list,
        const gchar *path
);

/*
 *	Saves the Devices List to the Devices List file.
 *
 *	The devices_list specifies the Devices List, a GList of
 *	edv_device_struct * Devices.
 *
 *	The path specifies the Devices List file.
 */
extern void EDVDeviceListFileSave(
        GList *devices_list,
        const gchar *path
);


#endif	/* EDV_DEVICES_LIST_H */
