/*
                            Filesystem Type
 */

#ifndef EDV_FS_TYPE_H
#define EDV_FS_TYPE_H

#include <glib.h>


typedef struct _edv_fs_type_struct	edv_fs_type_struct;
#define EDV_FS_TYPE(p)			((edv_fs_type_struct *)(p))


/*
 *	Flags:
 */
typedef enum {
	EDV_FS_TYPE_NO_DEVICE			= (1 << 0)
} edv_fs_type_flags;


/*
 *	Filesystem Type Codes & Names:
 */
#define EDV_FS_TYPE_EMPTY		0x0000

#define EDV_FS_TYPE_MSDOS		0x4d44
#define EDV_FS_TYPE_MSDOS_NAME		"msdos"

#define EDV_FS_TYPE_VFAT		0x4d45	/* This is really msdos, 0x4d44 */
#define EDV_FS_TYPE_VFAT_NAME		"vfat"

#define EDV_FS_TYPE_ISO9660		0x9660
#define EDV_FS_TYPE_ISO9660_NAME	"iso9660"

#define EDV_FS_TYPE_HPFS		0xF995E849
#define EDV_FS_TYPE_HPFS_NAME		"hpfs"

#define EDV_FS_TYPE_EXT			0x137D
#define EDV_FS_TYPE_EXT_NAME		"ext"

#define EDV_FS_TYPE_EXT2		0xEF53
#define EDV_FS_TYPE_EXT2_NAME		"ext2"
#define EDV_FS_TYPE_EXT2_OLD		0xEF51
#define EDV_FS_TYPE_EXT2_OLD_NAME	"ext2"

#define EDV_FS_TYPE_EXT3		0xEF53	/* Same as EDV_FS_TYPE_EXT2 */
#define EDV_FS_TYPE_EXT3_NAME		"ext3"

#define EDV_FS_TYPE_MINIX		0x138F            
#define EDV_FS_TYPE_MINIX_NAME		"minix"           
#define EDV_FS_TYPE_MINIX_ORIG		0x137F
#define EDV_FS_TYPE_MINIX_ORIG_NAME	"minix"

#define EDV_FS_TYPE_MINIX2		0x2468
#define EDV_FS_TYPE_MINIX2_NAME		"minix2"
#define EDV_FS_TYPE_MINIX2_EXT		0x138F
#define EDV_FS_TYPE_MINIX2_EXT_NAME	"minix2"

#define EDV_FS_TYPE_NCP			0x564c
#define EDV_FS_TYPE_NCP_NAME		"ncp"

#define EDV_FS_TYPE_NFS			0x6969
#define EDV_FS_TYPE_NFS_NAME		"nfs"

#define EDV_FS_TYPE_SMB			0x517B
#define EDV_FS_TYPE_SMB_NAME		"smb"

#define EDV_FS_TYPE_XENIX		0x012FF7B4
#define EDV_FS_TYPE_XENIX_NAME		"xenix"

#define EDV_FS_TYPE_SYSV4		0x012FF7B5
#define EDV_FS_TYPE_SYSV4_NAME		"sysv4"

#define EDV_FS_TYPE_SYSV2		0x012FF7B6
#define EDV_FS_TYPE_SYSV2_NAME		"sysv2"

#define EDV_FS_TYPE_COH			0x012FF7B7
#define EDV_FS_TYPE_COH_NAME		"coh"

#define EDV_FS_TYPE_UFS			0x00011954
#define EDV_FS_TYPE_UFS_NAME		"ufs"

#define EDV_FS_TYPE_XIA			0x012FD16D
#define EDV_FS_TYPE_XIA_NAME		"xia"


#define EDV_FS_TYPE_SWAP                0x0050  /* Universal swap */
#define EDV_FS_TYPE_SWAP_NAME           "swap"

#define EDV_FS_TYPE_PROC		0x9fa0
#define EDV_FS_TYPE_PROC_NAME		"proc"


/*
 *	Filesystems List:
 *
 *	List of filesystem type conical names and their codes.
 *
 *	Each entry must be <name>, <code>, <flags> so that they align
 *	with the members of edv_fs_type_struct.
 */
#define EDV_FS_TYPE_LIST	{				\
{ EDV_FS_TYPE_MSDOS_NAME,	EDV_FS_TYPE_MSDOS,	0 },	\
{ EDV_FS_TYPE_VFAT_NAME,	EDV_FS_TYPE_VFAT,	0 },	\
								\
{ EDV_FS_TYPE_ISO9660_NAME,	EDV_FS_TYPE_ISO9660,	0 },	\
								\
{ EDV_FS_TYPE_HPFS_NAME,	EDV_FS_TYPE_HPFS,	0 },	\
								\
{ EDV_FS_TYPE_EXT_NAME,		EDV_FS_TYPE_EXT,	0 },	\
{ EDV_FS_TYPE_EXT2_NAME,	EDV_FS_TYPE_EXT2,	0 },	\
{ EDV_FS_TYPE_EXT3_NAME,	EDV_FS_TYPE_EXT3,	0 },	\
								\
{ EDV_FS_TYPE_MINIX_NAME,	EDV_FS_TYPE_MINIX,	0 },	\
{ EDV_FS_TYPE_MINIX2_NAME,	EDV_FS_TYPE_MINIX2,	0 },	\
								\
{ EDV_FS_TYPE_NCP_NAME,		EDV_FS_TYPE_NCP,	0 },	\
{ EDV_FS_TYPE_NFS_NAME,		EDV_FS_TYPE_NFS,	0 },	\
{ EDV_FS_TYPE_SMB_NAME,		EDV_FS_TYPE_SMB,	0 },	\
								\
{ EDV_FS_TYPE_XENIX_NAME,	EDV_FS_TYPE_XENIX,	0 },	\
{ EDV_FS_TYPE_SYSV4_NAME,	EDV_FS_TYPE_SYSV4,	0 },	\
{ EDV_FS_TYPE_SYSV2_NAME,	EDV_FS_TYPE_SYSV2,	0 },	\
								\
{ EDV_FS_TYPE_COH_NAME,		EDV_FS_TYPE_COH,	0 },	\
{ EDV_FS_TYPE_UFS_NAME,		EDV_FS_TYPE_UFS,	0 },	\
{ EDV_FS_TYPE_XIA_NAME,		EDV_FS_TYPE_XIA,	0 },	\
								\
{ EDV_FS_TYPE_SWAP_NAME,	EDV_FS_TYPE_SWAP,	0 },	\
{ EDV_FS_TYPE_PROC_NAME,	EDV_FS_TYPE_PROC,	0 },	\
								\
{ NULL,				0,			0 }	\
}
/*
 *	Filesystem Type:
 */
struct _edv_fs_type_struct {
	gchar		*name;		/* Filesystem's conical name */
	guint32		code;		/* One of EDV_FS_TYPE_* */
	edv_fs_type_flags	flags;
};


/* Filesystem Name & Type Conversion */
extern guint32 EDVFSTypeGetCodeFromName(const gchar *name);
extern const gchar *EDVFSTypeGetNameFromCode(const guint32 code);

/* Filesystem Types List */
extern GList *EDVFSTypesListGetFromSystem(void);

/* Filesystem Type */
extern edv_fs_type_struct *EDVFSTypeNew(void);
extern edv_fs_type_struct *EDVFSTypeCopy(edv_fs_type_struct *fs_type);
extern void EDVFSTypeDelete(edv_fs_type_struct *fs_type);


#endif	/* EDV_FS_TYPE_H */
