/*
		       Endeavour Data Types & Enumerations
 */

#ifndef EDV_TYPES_H
#define EDV_TYPES_H


/*
 *	Size Format:
 */
typedef enum {
	EDV_SIZE_FORMAT_RAW,			/* 123456679 */
	EDV_SIZE_FORMAT_DELIMINATED,		/* 123,456,679 */
	EDV_SIZE_FORMAT_BLOCKS,			/* 1.2K, 923K, 1232K */
	EDV_SIZE_FORMAT_HUMAN_READABLE		/* 1.2K, 234M, 2G */
} edv_size_format;


/*
 *	Object Types:
 */
typedef enum {
	EDV_OBJECT_TYPE_UNKNOWN			= 0,
	EDV_OBJECT_TYPE_FILE			= 1,
	EDV_OBJECT_TYPE_DIRECTORY		= 2,
	EDV_OBJECT_TYPE_LINK			= 3,
	EDV_OBJECT_TYPE_DEVICE_BLOCK		= 4,
	EDV_OBJECT_TYPE_DEVICE_CHARACTER	= 5,
	EDV_OBJECT_TYPE_FIFO			= 6,
	EDV_OBJECT_TYPE_SOCKET			= 7,
	EDV_OBJECT_TYPE_ERROR			= 128
} edv_object_type;


/*
 *	Location Types:
 */
typedef enum {
	EDV_LOCATION_TYPE_VFS,			/* On the Virtual File System */
	EDV_LOCATION_TYPE_RECBIN,		/* In the Recycle Bin */
	EDV_LOCATION_TYPE_ARCHIVE		/* In an archive */
} edv_location_type;


/*
 *	Permission Flags:
 */
typedef enum {
	/* User */
	EDV_PERMISSION_UEXECUTE		= (1 << 0),
	EDV_PERMISSION_UREAD		= (1 << 1),
	EDV_PERMISSION_UWRITE		= (1 << 2),

	/* Group */
	EDV_PERMISSION_GEXECUTE		= (1 << 3),
	EDV_PERMISSION_GREAD		= (1 << 4),
	EDV_PERMISSION_GWRITE		= (1 << 5),

	/* Anonymous/Other */
	EDV_PERMISSION_AEXECUTE		= (1 << 6),
	EDV_PERMISSION_AREAD		= (1 << 7),
	EDV_PERMISSION_AWRITE		= (1 << 8),

	/* SetUD, SetGID, Sticky */
	EDV_PERMISSION_SETUID		= (1 << 9),
	EDV_PERMISSION_SETGID		= (1 << 10),
	EDV_PERMISSION_STICKY		= (1 << 11)
} edv_permission_flags;


/*
 *	Operation ID Flags:
 */
typedef enum {
	EDV_OPID_ALLOW_MULTIPLE		= (1 << 0),	/* Allow more than one
							 * instance per list */
	EDV_OPID_NO_OP			= (1 << 1)	/* Does not perform an
							 * operation (eg for
							 * separators) */
} edv_opid_flags;


/*
 *	Delete Methods:
 */
typedef enum {
	EDV_DELETE_METHOD_RECYCLE	= 0,
	EDV_DELETE_METHOD_PURGE		= 1
} edv_delete_method;


/*
 *	MIME Type Classes:
 */
typedef enum {
	EDV_MIME_TYPE_CLASS_SYSTEM	= 0,	/* System object type */
	EDV_MIME_TYPE_CLASS_FORMAT	= 1,	/* File format */
	EDV_MIME_TYPE_CLASS_PROGRAM	= 2,	/* Program object */
	EDV_MIME_TYPE_CLASS_UNIQUE	= 3	/* Unique object */
} edv_mime_type_class;


/*
 *	MIME Type Handlers:
 */
typedef enum {
	EDV_MIME_TYPE_HANDLER_COMMAND		= 0,	/* Use Command */
	EDV_MIME_TYPE_HANDLER_EDV_ARCHIVER	= 1,	/* Use Archiver */
	EDV_MIME_TYPE_HANDLER_EDV_IMAGE_BROWSER	= 2,	/* Use Image Browser */
	EDV_MIME_TYPE_HANDLER_EDV_RECYCLE_BIN	= 3	/* Use Recycle Bin */
} edv_mime_type_handler;


/*
 *	History Types:
 */
typedef enum {
	EDV_HISTORY_UNKNOWN			= 0,
	EDV_HISTORY_SYNC_DISKS			= 1,
	EDV_HISTORY_SYNC_RECBIN			= 2,

	EDV_HISTORY_VFS_OBJECT_CREATE		= 10,
	EDV_HISTORY_VFS_OBJECT_COPY		= 11,
	EDV_HISTORY_VFS_OBJECT_MOVE		= 12,	/* Or rename */
	EDV_HISTORY_VFS_OBJECT_LINK		= 13,
	EDV_HISTORY_VFS_OBJECT_CHMOD		= 15,	/* Originally misordered */
	EDV_HISTORY_VFS_OBJECT_CHOWN		= 14,	/* Originally misordered */
	EDV_HISTORY_VFS_OBJECT_CHTIME		= 16,
	EDV_HISTORY_VFS_OBJECT_DOWNLOAD		= 17,
	EDV_HISTORY_VFS_OBJECT_DELETE		= 18,

	EDV_HISTORY_RECYCLED_OBJECT_RECOVER	= 20,
	EDV_HISTORY_RECYCLED_OBJECT_PURGE	= 21,
	EDV_HISTORY_RECYCLED_OBJECT_PURGE_ALL	= 22,
	EDV_HISTORY_RECYCLED_OBJECT_LINK	= 23,
	EDV_HISTORY_RECYCLED_OBJECT_RENAME	= 24,	/* Not move */
	EDV_HISTORY_RECYCLED_OBJECT_CHMOD	= 25,
	EDV_HISTORY_RECYCLED_OBJECT_CHOWN	= 26,
	EDV_HISTORY_RECYCLED_OBJECT_CHTIME	= 27,

	EDV_HISTORY_ARCHIVE_OBJECT_ADD		= 30,
	EDV_HISTORY_ARCHIVE_OBJECT_EXTRACT	= 31,
	EDV_HISTORY_ARCHIVE_OBJECT_DELETE	= 32,
	EDV_HISTORY_ARCHIVE_FIX			= 38
} edv_history_type;

/*
 *	Version 2.8.3 and older edv_history_type compatability:
 */
#define EDV_HISTORY_DISK_OBJECT_CREATE	EDV_HISTORY_VFS_OBJECT_CREATE
#define EDV_HISTORY_DISK_OBJECT_COPY	EDV_HISTORY_VFS_OBJECT_COPY
#define EDV_HISTORY_DISK_OBJECT_MOVE	EDV_HISTORY_VFS_OBJECT_MOVE
#define EDV_HISTORY_DISK_OBJECT_LINK	EDV_HISTORY_VFS_OBJECT_LINK
#define EDV_HISTORY_DISK_OBJECT_CHOWN	EDV_HISTORY_VFS_OBJECT_CHOWN
#define EDV_HISTORY_DISK_OBJECT_CHMOD	EDV_HISTORY_VFS_OBJECT_CHMOD
#define EDV_HISTORY_DISK_OBJECT_CHTIME	EDV_HISTORY_VFS_OBJECT_CHTIME
#define EDV_HISTORY_DISK_OBJECT_DOWNLOAD	EDV_HISTORY_VFS_OBJECT_DOWNLOAD
#define EDV_HISTORY_DISK_OBJECT_DELETE	EDV_HISTORY_VFS_OBJECT_DELETE


/*
 *	Lists Load Images Priorties:
 */
typedef enum {
	EDV_LISTS_LOAD_IMAGES_PRIORITY_HIGHEST,
	EDV_LISTS_LOAD_IMAGES_PRIORITY_HIGH,
	EDV_LISTS_LOAD_IMAGES_PRIORITY_NORMAL,
	EDV_LISTS_LOAD_IMAGES_PRIORITY_LOW,
	EDV_LISTS_LOAD_IMAGES_PRIORITY_LOWEST
} edv_lists_load_images_priority;


/*
 *	Window Types:
 */
typedef enum {
	EDV_WINDOW_NONE				= 0,
	EDV_WINDOW_ABOUT_DIALOG			= 500,
	EDV_WINDOW_FILE_BROWSER			= 1000,
	EDV_WINDOW_IMAGE_BROWSER		= 1100,
	EDV_WINDOW_ARCHIVER			= 2000,
	EDV_WINDOW_RECYCLE_BIN			= 5000,
	EDV_WINDOW_MIME_TYPES_LIST		= 6000,
	EDV_WINDOW_DEVICES_LIST			= 7000,
	EDV_WINDOW_HISTORY_LIST			= 8000,
	EDV_WINDOW_OPTIONS			= 9000,
	EDV_WINDOW_CUSTOMIZE			= 9100,
	EDV_WINDOW_PROPERTIES_DIALOG		= 10000,
	EDV_WINDOW_FIND				= 11000,
	EDV_WINDOW_OBJECT_OPERATIONS_DIALOG	= 11100,
	EDV_WINDOW_RUN_DIALOG			= 11200,
	EDV_WINDOW_HELP				= 50000
} edv_window_type;


/*
 *	Core Pending Operation Flags:
 */
typedef enum {
	EDV_CORE_PENDING_CLOSE_ALL_WINDOWS	= (1 << 0),
	EDV_CORE_PENDING_RESET			= (1 << 1)
} edv_core_pending_flags;


/*
 *	Core:
 *
 *	Forward declaration, see endeavour2.h for complete declaration.
 */
typedef struct _edv_core_struct         edv_core_struct;


#endif	/* EDV_TYPES_H */
